==> carpet-addons-not-found-1.18.2-2.1.0-sources.jar: carpetaddonsnotfound/mixins/FlowerBlockMixin.java <==
package carpetaddonsnotfound.mixins;

import org.spongepowered.asm.mixin.Mixin;

import static carpetaddonsnotfound.CarpetAddonsNotFoundSettings.ReplaceableFlowersOptions;
import static carpetaddonsnotfound.CarpetAddonsNotFoundSettings.replaceableFlowers;

import carpetaddonsnotfound.CarpetAddonsNotFoundSettings.ReplaceableFlowersOptions;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2356;
import net.minecraft.class_2680;

@Mixin(class_2356.class)
public abstract class FlowerBlockMixin extends class_2248 {
  public FlowerBlockMixin(class_2251 settings) {
    super(settings);
  }

  @Override
  public boolean method_9616(class_2680 state, class_1750 context) {
    if (replaceableFlowers == ReplaceableFlowersOptions.FALSE) {
      return super.method_9616(state, context);
    }
    //From AbstrackBlock.canReplace but without BlockState.isReplacable check.
    return context.method_8041().method_7960() || !context.method_8041().method_31574(this.method_8389());
  }

  @Override
  public void method_9536(
          class_2680 state,
          //#if MC>12104
          //$$ ServerWorld world,
          //#else
          class_1937 world,
          //#endif
          class_2338 pos,
          //#if MC<12105
          class_2680 newState,
          //#endif
          boolean moved) {
    class_2680 blockState;
    //#if MC>12104
    //$$ blockState = state;
    //#else
    blockState = newState;
    //#endif
    if (replaceableFlowers != ReplaceableFlowersOptions.FALSE && !blockState.method_26215() && !moved) {
      method_9577(world, pos, new class_1799(this.method_8389(), 1));
    }

    //#if MC>12104
    //$$ super.onStateReplaced(blockState, world, pos, moved);
    //#else
    super.method_9536(state, world, pos, blockState, moved);
    //#endif
  }
}

==> carpet-addons-not-found-1.21.10-2.2.0-sources.jar: carpetaddonsnotfound/mixins/FlowerBlockMixin.java <==
package carpetaddonsnotfound.mixins;

import org.spongepowered.asm.mixin.Mixin;

import static carpetaddonsnotfound.CarpetAddonsNotFoundSettings.ReplaceableFlowersOptions;
import static carpetaddonsnotfound.CarpetAddonsNotFoundSettings.replaceableFlowers;

import carpetaddonsnotfound.CarpetAddonsNotFoundSettings.ReplaceableFlowersOptions;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2356;
import net.minecraft.class_2680;
import net.minecraft.class_3218;

@Mixin(class_2356.class)
public abstract class FlowerBlockMixin extends class_2248 {
  public FlowerBlockMixin(class_2251 settings) {
    super(settings);
  }

  @Override
  public boolean method_9616(class_2680 state, class_1750 context) {
    if (replaceableFlowers == ReplaceableFlowersOptions.FALSE) {
      return super.method_9616(state, context);
    }
    //From AbstrackBlock.canReplace but without BlockState.isReplacable check.
    return context.method_8041().method_7960() || !context.method_8041().method_31574(this.method_8389());
  }

  @Override
  public void method_66388(
          class_2680 state,
          //#if MC>12104
          class_3218 world,
          //#else
          //$$ World world,
          //#endif
          class_2338 pos,
          //#if MC<12105
          //$$ BlockState newState,
          //#endif
          boolean moved) {
    class_2680 blockState;
    //#if MC>12104
    blockState = state;
    //#else
    //$$ blockState = newState;
    //#endif
    if (replaceableFlowers != ReplaceableFlowersOptions.FALSE && !blockState.method_26215() && !moved) {
      method_9577(world, pos, new class_1799(this.method_8389(), 1));
    }

    //#if MC>12104
    super.method_66388(blockState, world, pos, moved);
    //#else
    //$$ super.onStateReplaced(state, world, pos, blockState, moved);
    //#endif
  }
}
